import { CommonChart, Coordinate2D, XaxisType, YaxisType, ChartProvider } from '@oneteme/jquery-core';
import { ElementRef, EventEmitter, NgZone, SimpleChanges } from '@angular/core';
import ApexCharts from 'apexcharts';
import { Subscription } from 'rxjs';
export type ChartCustomEvent = 'previous' | 'next' | 'pivot';
/**
 * Crée les boutons personnalisés pour la barre d'outils
 */
export declare function customIcons(event: (arg: ChartCustomEvent) => void, canPivot: boolean): any[];
export declare function determineXAxisDataType(value: any): string;
/**
 * Détermine le type d'axe X en fonction des données
 */
export declare function getType<X extends XaxisType, Y extends YaxisType | Coordinate2D>(commonChart: CommonChart<X, Y>): string;
/**
 * Initialise les options de base communes à tous les graphiques
 */
export declare function initCommonChartOptions(node: ElementRef, customEvent: EventEmitter<ChartCustomEvent>, ngZone: NgZone, chartType: string, canPivot?: boolean): {
    shouldRedraw: boolean;
    chart: {
        type: string;
        toolbar: {
            show: boolean;
            tools: {
                download: boolean;
                selection: boolean;
                zoom: boolean;
                zoomin: boolean;
                zoomout: boolean;
                pan: boolean;
                reset: boolean;
                customIcons: any[];
            };
        };
        events: {
            mouseMove: () => void;
            mouseLeave: () => void;
        };
        zoom: {
            enabled: boolean;
        };
    };
    series: any[];
    noData: {
        text: string;
    };
    xaxis: {};
    plotOptions: {};
};
/**
 * Met à jour les options communes du graphique en fonction de la configuration fournie
 */
export declare function updateCommonOptions<X extends XaxisType, Y extends YaxisType>(options: any, config: ChartProvider<X, Y>): any;
/**
 * Initialise un graphique ApexCharts de façon sécurisée
 */
export declare function initChart(el: ElementRef, ngZone: NgZone, options: any, chartInstance: any, subscription: Subscription, debug: boolean): ApexCharts;
/**
 * Met à jour les options du graphique de manière sécurisée
 */
export declare function updateChartOptions(chartInstance: ApexCharts | null, ngZone: NgZone, options: any, redrawPaths?: boolean, animate?: boolean, updateSyncedCharts?: boolean): Promise<void>;
/**
 * Fonction commune pour gérer l'hydratation des graphiques
 */
export declare function hydrateChart(changes: SimpleChanges, data: any[], chartConfig: ChartProvider<any, any>, options: any, chartInstance: any, ngZone: NgZone, updateDataFn: Function, destroyFn: Function, initFn: Function, updateOptionsFn: Function, debug: boolean): void;
/**
 * Fonction commune pour la destruction propre des graphiques
 */
export declare function destroyChart(chartInstance: any, subscription: Subscription): void;
